from __future__ import print_function
from algowrap import err_constants as err_cnsts
"""
This file handles the exception raise during validation of input files.
For each exception a class is associated so that we can add methods acc-
ording to the need.

This file also contains handle error function which can be used as decorator
to catch the exception raises.


"""

class FileExistError(Exception):
    def __init__(self, arg = err_cnsts.INPUTERR10_FILE_EXISTS_ERROR):
        self.message = arg

class FileExtensionError(Exception):
    def __init__(self, arg = err_cnsts.INPUTERR4_INVALID_FILE_FORMAT):
        self.message = arg

class FileEmptyError(Exception):
    def __init__(self, arg = err_cnsts.INPUTERR11_FILE_EMPTY_ERROR):
        self.message = arg

class InvalidMavenError(Exception):
    def __init__(self, arg = err_cnsts.INPUTERR12_INVALID_MAVEN_ERROR):
        self.message = arg

class InvalidFileError(Exception):
    def __init__(self, arg = err_cnsts.INPUTERR14_INVALID_FILE_ERROR):
        self.message = arg


def handleError(function):
    def runFunction(*args,**kwargs):
        try:
            return function(*args)
        except FileEmptyError as e:
            print(e.message)
            raise

        except FileExtensionError as e:
            print(e.message)
            raise

        except FileExistError as e:
            print(e.message)
            raise

        except InvalidMavenError as e:
            print(e.message)
            raise

        except Exception as e:
            print("Error Not Known")
            raise


    return runFunction
